#!/usr/bin/ruby

require 'optparse'
require 'pp'

require_relative '../lib/nifi_sdk_ruby'

options = {
  :id        => nil,
  :threshold => nil,
}

OptionParser.new do |o|
    o.banner = "Usage: setup_with_schedule.rb [options]"

    o.on('-i', '--id ID', Integer, ) { |v| options[:id] = v }
    o.on('-t', '--threshold THRESHOLD', Integer ) { |v| options[:threshold] = v }
    o.on('-v', '--verbose', 'Verbose') { |v| options[:verbose] = v }
    o.on('-h', '--help', 'Displays Help') do
      puts o
      exit
    end
end.parse!

options.each do |k, v|
    argument_errors.concat("#{k} argument is mandatory.\n") if options[k.to_sym].nil?
end


nifi_client = Nifi.new()
nifi_client.set_debug true

# Get the ID of Root Process Group
pg_root = nifi_client.get_process_group
puts "\n"
puts "PG Root's ID"
puts "\n"
puts pg_root['id']
puts "\n"

# Create new Process Group
puts "Create new PG"
puts "\n"
new_pg = nifi_client.create_process_group(:name => 'test')
puts "\n"
puts new_pg
puts "\n"

# Get all attrs of the Process Group by ID (PG Root's child)
puts 'PG ' + new_pg['id'] + ' attrs.'
puts "\n"
puts nifi_client.get_process_group(new_pg['id'])
puts "\n"

# Get a Process Group ID
puts "PG ID"
puts "\n"
pg = nifi_client.get_process_group(new_pg['id'])
puts pg['id']
puts "\n"

# Delete some Process Group
puts 'Delete PG with id ' + new_pg['id']
puts "\n"
puts nifi_client.delete_process_group new_pg['id']
puts "\n"

# Upload a template to Root Process Group
puts 'Upload template to Root PG'
puts nifi_client.upload_template(:path => 'IN.hmStaff.taskStatus.xml')
